@@ -50,6 +50,7 @@ ags_drum_open_callback(GtkWidget *toggle_button, AgsDrum *drum)
   gchar *bookmark_filename;
   gchar *home_path;
   gchar *sandbox_path;
+  gchar *current_path;
   gchar *str;
 
   gchar *drumkits_bookmark_filename;
@@ -155,35 +156,36 @@ ags_drum_open_callback(GtkWidget *toggle_button, AgsDrum *drum)
 
   ags_file_widget_read_bookmark(file_widget);
 
+  /* current path */
+  current_path = NULL;
+    
 #if defined(AGS_MACOS_SANDBOX)
-  ags_file_widget_set_flags(file_widget,
-			    AGS_FILE_WIDGET_APP_SANDBOX);
-
-  ags_file_widget_set_current_path(file_widget,
-				   sandbox_path);
+  current_path = g_strdup(home_path);
 #endif
 
 #if defined(AGS_FLATPAK_SANDBOX)
   ags_file_widget_set_flags(file_widget,
 			    AGS_FILE_WIDGET_APP_SANDBOX);
 
-  ags_file_widget_set_current_path(file_widget,
-				   sandbox_path);
+  current_path = g_strdup(sandbox_path);
 #endif
 
 #if defined(AGS_SNAP_SANDBOX)
   ags_file_widget_set_flags(file_widget,
 			    AGS_FILE_WIDGET_APP_SANDBOX);
 
-  ags_file_widget_set_current_path(file_widget,
-				   sandbox_path);
+  current_path = g_strdup(sandbox_path);
 #endif
   
 #if !defined(AGS_MACOS_SANDBOX) && !defined(AGS_FLATPAK_SANDBOX) && !defined(AGS_SNAP_SANDBOX)
-  ags_file_widget_set_current_path(file_widget,
-				   home_path);
+  current_path = g_strdup(home_path);
 #endif
 
+  ags_file_widget_set_current_path(file_widget,
+				   current_path);
+
+  g_free(current_path);
+
   ags_file_widget_refresh(file_widget);
 
   ags_file_widget_add_location(file_widget,
